# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: pipeline_spec.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'pipeline_spec.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13pipeline_spec.proto\x12\x0cml_pipelines\x1a\x1egoogle/protobuf/duration.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x17google/rpc/status.proto\"\xa3\x05\n\x0bPipelineJob\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12.\n\rpipeline_spec\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x35\n\x06labels\x18\x0b \x03(\x0b\x32%.ml_pipelines.PipelineJob.LabelsEntry\x12?\n\x0eruntime_config\x18\x0c \x01(\x0b\x32\'.ml_pipelines.PipelineJob.RuntimeConfig\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\xee\x02\n\rRuntimeConfig\x12O\n\nparameters\x18\x01 \x03(\x0b\x32\x37.ml_pipelines.PipelineJob.RuntimeConfig.ParametersEntryB\x02\x18\x01\x12\x1c\n\x14gcs_output_directory\x18\x02 \x01(\t\x12V\n\x10parameter_values\x18\x03 \x03(\x0b\x32<.ml_pipelines.PipelineJob.RuntimeConfig.ParameterValuesEntry\x1a\x46\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\"\n\x05value\x18\x02 \x01(\x0b\x32\x13.ml_pipelines.Value:\x02\x38\x01\x1aN\n\x14ParameterValuesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.Value:\x02\x38\x01J\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06J\x04\x08\x06\x10\x07J\x04\x08\x08\x10\tJ\x04\x08\t\x10\nJ\x04\x08\n\x10\x0b\"\xf7\x03\n\x0cPipelineSpec\x12\x31\n\rpipeline_info\x18\x01 \x01(\x0b\x32\x1a.ml_pipelines.PipelineInfo\x12\x30\n\x0f\x64\x65ployment_spec\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x13\n\x0bsdk_version\x18\x04 \x01(\t\x12\x16\n\x0eschema_version\x18\x05 \x01(\t\x12>\n\ncomponents\x18\x08 \x03(\x0b\x32*.ml_pipelines.PipelineSpec.ComponentsEntry\x12)\n\x04root\x18\t \x01(\x0b\x32\x1b.ml_pipelines.ComponentSpec\x12\x1d\n\x15\x64\x65\x66\x61ult_pipeline_root\x18\n \x01(\t\x1a{\n\x10RuntimeParameter\x12;\n\x04type\x18\x01 \x01(\x0e\x32-.ml_pipelines.PrimitiveType.PrimitiveTypeEnum\x12*\n\rdefault_value\x18\x02 \x01(\x0b\x32\x13.ml_pipelines.Value\x1aN\n\x0f\x43omponentsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.ml_pipelines.ComponentSpec:\x02\x38\x01\"\xe7\x02\n\rComponentSpec\x12<\n\x11input_definitions\x18\x01 \x01(\x0b\x32!.ml_pipelines.ComponentInputsSpec\x12>\n\x12output_definitions\x18\x02 \x01(\x0b\x32\".ml_pipelines.ComponentOutputsSpec\x12$\n\x03\x64\x61g\x18\x03 \x01(\x0b\x32\x15.ml_pipelines.DagSpecH\x00\x12\x18\n\x0e\x65xecutor_label\x18\x04 \x01(\tH\x00\x12?\n\x15single_platform_specs\x18\x05 \x03(\x0b\x32 .ml_pipelines.SinglePlatformSpec\x12\x45\n\x18task_config_passthroughs\x18\x06 \x03(\x0b\x32#.ml_pipelines.TaskConfigPassthroughB\x10\n\x0eimplementation\"\xb7\x01\n\x07\x44\x61gSpec\x12/\n\x05tasks\x18\x01 \x03(\x0b\x32 .ml_pipelines.DagSpec.TasksEntry\x12-\n\x07outputs\x18\x02 \x01(\x0b\x32\x1c.ml_pipelines.DagOutputsSpec\x1aL\n\nTasksEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12-\n\x05value\x18\x02 \x01(\x0b\x32\x1e.ml_pipelines.PipelineTaskSpec:\x02\x38\x01\"\x95\t\n\x0e\x44\x61gOutputsSpec\x12>\n\tartifacts\x18\x01 \x03(\x0b\x32+.ml_pipelines.DagOutputsSpec.ArtifactsEntry\x12@\n\nparameters\x18\x02 \x03(\x0b\x32,.ml_pipelines.DagOutputsSpec.ParametersEntry\x1aM\n\x14\x41rtifactSelectorSpec\x12\x18\n\x10producer_subtask\x18\x01 \x01(\t\x12\x1b\n\x13output_artifact_key\x18\x02 \x01(\t\x1a\x66\n\x15\x44\x61gOutputArtifactSpec\x12M\n\x12\x61rtifact_selectors\x18\x01 \x03(\x0b\x32\x31.ml_pipelines.DagOutputsSpec.ArtifactSelectorSpec\x1a\x64\n\x0e\x41rtifactsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x41\n\x05value\x18\x02 \x01(\x0b\x32\x32.ml_pipelines.DagOutputsSpec.DagOutputArtifactSpec:\x02\x38\x01\x1aO\n\x15ParameterSelectorSpec\x12\x18\n\x10producer_subtask\x18\x01 \x01(\t\x12\x1c\n\x14output_parameter_key\x18\x02 \x01(\t\x1ai\n\x16ParameterSelectorsSpec\x12O\n\x13parameter_selectors\x18\x01 \x03(\x0b\x32\x32.ml_pipelines.DagOutputsSpec.ParameterSelectorSpec\x1a\xf1\x01\n\x19MapParameterSelectorsSpec\x12g\n\x11mapped_parameters\x18\x02 \x03(\x0b\x32L.ml_pipelines.DagOutputsSpec.MapParameterSelectorsSpec.MappedParametersEntry\x1ak\n\x15MappedParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x41\n\x05value\x18\x02 \x01(\x0b\x32\x32.ml_pipelines.DagOutputsSpec.ParameterSelectorSpec:\x02\x38\x01\x1a\xcb\x01\n\x16\x44\x61gOutputParameterSpec\x12R\n\x14value_from_parameter\x18\x01 \x01(\x0b\x32\x32.ml_pipelines.DagOutputsSpec.ParameterSelectorSpecH\x00\x12O\n\x10value_from_oneof\x18\x02 \x01(\x0b\x32\x33.ml_pipelines.DagOutputsSpec.ParameterSelectorsSpecH\x00\x42\x06\n\x04kindJ\x04\x08\x03\x10\x04\x1a\x66\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x42\n\x05value\x18\x02 \x01(\x0b\x32\x33.ml_pipelines.DagOutputsSpec.DagOutputParameterSpec:\x02\x38\x01\"\xe8\x05\n\x13\x43omponentInputsSpec\x12\x43\n\tartifacts\x18\x01 \x03(\x0b\x32\x30.ml_pipelines.ComponentInputsSpec.ArtifactsEntry\x12\x45\n\nparameters\x18\x02 \x03(\x0b\x32\x31.ml_pipelines.ComponentInputsSpec.ParametersEntry\x1a\x8b\x01\n\x0c\x41rtifactSpec\x12\x37\n\rartifact_type\x18\x01 \x01(\x0b\x32 .ml_pipelines.ArtifactTypeSchema\x12\x18\n\x10is_artifact_list\x18\x02 \x01(\x08\x12\x13\n\x0bis_optional\x18\x03 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x1a\xf0\x01\n\rParameterSpec\x12?\n\x04type\x18\x01 \x01(\x0e\x32-.ml_pipelines.PrimitiveType.PrimitiveTypeEnumB\x02\x18\x01\x12\x45\n\x0eparameter_type\x18\x02 \x01(\x0e\x32-.ml_pipelines.ParameterType.ParameterTypeEnum\x12-\n\rdefault_value\x18\x03 \x01(\x0b\x32\x16.google.protobuf.Value\x12\x13\n\x0bis_optional\x18\x04 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x1a`\n\x0e\x41rtifactsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12=\n\x05value\x18\x02 \x01(\x0b\x32..ml_pipelines.ComponentInputsSpec.ArtifactSpec:\x02\x38\x01\x1a\x62\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12>\n\x05value\x18\x02 \x01(\x0b\x32/.ml_pipelines.ComponentInputsSpec.ParameterSpec:\x02\x38\x01\"\xb8\x08\n\x14\x43omponentOutputsSpec\x12\x44\n\tartifacts\x18\x01 \x03(\x0b\x32\x31.ml_pipelines.ComponentOutputsSpec.ArtifactsEntry\x12\x46\n\nparameters\x18\x02 \x03(\x0b\x32\x32.ml_pipelines.ComponentOutputsSpec.ParametersEntry\x1a\x9a\x04\n\x0c\x41rtifactSpec\x12\x37\n\rartifact_type\x18\x01 \x01(\x0b\x32 .ml_pipelines.ArtifactTypeSchema\x12W\n\nproperties\x18\x02 \x03(\x0b\x32?.ml_pipelines.ComponentOutputsSpec.ArtifactSpec.PropertiesEntryB\x02\x18\x01\x12\x64\n\x11\x63ustom_properties\x18\x03 \x03(\x0b\x32\x45.ml_pipelines.ComponentOutputsSpec.ArtifactSpec.CustomPropertiesEntryB\x02\x18\x01\x12)\n\x08metadata\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x18\n\x10is_artifact_list\x18\x05 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x1aX\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x34\n\x05value\x18\x02 \x01(\x0b\x32%.ml_pipelines.ValueOrRuntimeParameter:\x02\x38\x01\x1a^\n\x15\x43ustomPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x34\n\x05value\x18\x02 \x01(\x0b\x32%.ml_pipelines.ValueOrRuntimeParameter:\x02\x38\x01\x1a\xac\x01\n\rParameterSpec\x12?\n\x04type\x18\x01 \x01(\x0e\x32-.ml_pipelines.PrimitiveType.PrimitiveTypeEnumB\x02\x18\x01\x12\x45\n\x0eparameter_type\x18\x02 \x01(\x0e\x32-.ml_pipelines.ParameterType.ParameterTypeEnum\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x1a\x61\n\x0e\x41rtifactsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12>\n\x05value\x18\x02 \x01(\x0b\x32/.ml_pipelines.ComponentOutputsSpec.ArtifactSpec:\x02\x38\x01\x1a\x63\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12?\n\x05value\x18\x02 \x01(\x0b\x32\x30.ml_pipelines.ComponentOutputsSpec.ParameterSpec:\x02\x38\x01\"\xc2\x08\n\x0eTaskInputsSpec\x12@\n\nparameters\x18\x01 \x03(\x0b\x32,.ml_pipelines.TaskInputsSpec.ParametersEntry\x12>\n\tartifacts\x18\x02 \x03(\x0b\x32+.ml_pipelines.TaskInputsSpec.ArtifactsEntry\x1a\xfa\x01\n\x11InputArtifactSpec\x12\x65\n\x14task_output_artifact\x18\x03 \x01(\x0b\x32\x45.ml_pipelines.TaskInputsSpec.InputArtifactSpec.TaskOutputArtifactSpecH\x00\x12\"\n\x18\x63omponent_input_artifact\x18\x04 \x01(\tH\x00\x1aL\n\x16TaskOutputArtifactSpec\x12\x15\n\rproducer_task\x18\x01 \x01(\t\x12\x1b\n\x13output_artifact_key\x18\x02 \x01(\tB\x06\n\x04kindJ\x04\x08\x05\x10\x06\x1a\xea\x03\n\x12InputParameterSpec\x12h\n\x15task_output_parameter\x18\x01 \x01(\x0b\x32G.ml_pipelines.TaskInputsSpec.InputParameterSpec.TaskOutputParameterSpecH\x00\x12>\n\rruntime_value\x18\x02 \x01(\x0b\x32%.ml_pipelines.ValueOrRuntimeParameterH\x00\x12#\n\x19\x63omponent_input_parameter\x18\x03 \x01(\tH\x00\x12\\\n\x11task_final_status\x18\x05 \x01(\x0b\x32?.ml_pipelines.TaskInputsSpec.InputParameterSpec.TaskFinalStatusH\x00\x12%\n\x1dparameter_expression_selector\x18\x04 \x01(\t\x1aN\n\x17TaskOutputParameterSpec\x12\x15\n\rproducer_task\x18\x01 \x01(\t\x12\x1c\n\x14output_parameter_key\x18\x02 \x01(\t\x1a(\n\x0fTaskFinalStatus\x12\x15\n\rproducer_task\x18\x01 \x01(\tB\x06\n\x04kind\x1a\x62\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12>\n\x05value\x18\x02 \x01(\x0b\x32/.ml_pipelines.TaskInputsSpec.InputParameterSpec:\x02\x38\x01\x1a`\n\x0e\x41rtifactsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12=\n\x05value\x18\x02 \x01(\x0b\x32..ml_pipelines.TaskInputsSpec.InputArtifactSpec:\x02\x38\x01\"\xf6\x06\n\x0fTaskOutputsSpec\x12\x41\n\nparameters\x18\x01 \x03(\x0b\x32-.ml_pipelines.TaskOutputsSpec.ParametersEntry\x12?\n\tartifacts\x18\x02 \x03(\x0b\x32,.ml_pipelines.TaskOutputsSpec.ArtifactsEntry\x1a\xc0\x03\n\x12OutputArtifactSpec\x12\x37\n\rartifact_type\x18\x01 \x01(\x0b\x32 .ml_pipelines.ArtifactTypeSchema\x12T\n\nproperties\x18\x02 \x03(\x0b\x32@.ml_pipelines.TaskOutputsSpec.OutputArtifactSpec.PropertiesEntry\x12\x61\n\x11\x63ustom_properties\x18\x03 \x03(\x0b\x32\x46.ml_pipelines.TaskOutputsSpec.OutputArtifactSpec.CustomPropertiesEntry\x1aX\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x34\n\x05value\x18\x02 \x01(\x0b\x32%.ml_pipelines.ValueOrRuntimeParameter:\x02\x38\x01\x1a^\n\x15\x43ustomPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x34\n\x05value\x18\x02 \x01(\x0b\x32%.ml_pipelines.ValueOrRuntimeParameter:\x02\x38\x01\x1aR\n\x13OutputParameterSpec\x12;\n\x04type\x18\x01 \x01(\x0e\x32-.ml_pipelines.PrimitiveType.PrimitiveTypeEnum\x1a\x64\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12@\n\x05value\x18\x02 \x01(\x0b\x32\x31.ml_pipelines.TaskOutputsSpec.OutputParameterSpec:\x02\x38\x01\x1a\x62\n\x0e\x41rtifactsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12?\n\x05value\x18\x02 \x01(\x0b\x32\x30.ml_pipelines.TaskOutputsSpec.OutputArtifactSpec:\x02\x38\x01\"m\n\rPrimitiveType\"X\n\x11PrimitiveTypeEnum\x12\x1e\n\x1aPRIMITIVE_TYPE_UNSPECIFIED\x10\x00\x12\x07\n\x03INT\x10\x01\x12\n\n\x06\x44OUBLE\x10\x02\x12\n\n\x06STRING\x10\x03\x1a\x02\x18\x01:\x02\x18\x01\"\xc8\x01\n\rParameterType\"\xb6\x01\n\x11ParameterTypeEnum\x12#\n\x1fPARAMETER_TYPE_ENUM_UNSPECIFIED\x10\x00\x12\x11\n\rNUMBER_DOUBLE\x10\x01\x12\x12\n\x0eNUMBER_INTEGER\x10\x02\x12\n\n\x06STRING\x10\x03\x12\x0b\n\x07\x42OOLEAN\x10\x04\x12\x08\n\x04LIST\x10\x05\x12\n\n\x06STRUCT\x10\x06\x12\x15\n\x11TASK_FINAL_STATUS\x10\x07\x12\x0f\n\x0bTASK_CONFIG\x10\x08\"\xca\x01\n\x19TaskConfigPassthroughType\"\xac\x01\n\x1dTaskConfigPassthroughTypeEnum\x12\x08\n\x04NONE\x10\x00\x12\r\n\tRESOURCES\x10\x01\x12\x07\n\x03\x45NV\x10\x02\x12\x17\n\x13KUBERNETES_AFFINITY\x10\x03\x12\x1a\n\x16KUBERNETES_TOLERATIONS\x10\x04\x12\x1c\n\x18KUBERNETES_NODE_SELECTOR\x10\x05\x12\x16\n\x12KUBERNETES_VOLUMES\x10\x06\"\x84\x01\n\x15TaskConfigPassthrough\x12T\n\x05\x66ield\x18\x01 \x01(\x0e\x32\x45.ml_pipelines.TaskConfigPassthroughType.TaskConfigPassthroughTypeEnum\x12\x15\n\rapply_to_task\x18\x02 \x01(\x08\"\xec\x08\n\x10PipelineTaskSpec\x12\x31\n\ttask_info\x18\x01 \x01(\x0b\x32\x1e.ml_pipelines.PipelineTaskInfo\x12,\n\x06inputs\x18\x02 \x01(\x0b\x32\x1c.ml_pipelines.TaskInputsSpec\x12\x17\n\x0f\x64\x65pendent_tasks\x18\x05 \x03(\t\x12\x46\n\x0f\x63\x61\x63hing_options\x18\x06 \x01(\x0b\x32-.ml_pipelines.PipelineTaskSpec.CachingOptions\x12\x31\n\rcomponent_ref\x18\x07 \x01(\x0b\x32\x1a.ml_pipelines.ComponentRef\x12\x44\n\x0etrigger_policy\x18\x08 \x01(\x0b\x32,.ml_pipelines.PipelineTaskSpec.TriggerPolicy\x12?\n\x11\x61rtifact_iterator\x18\t \x01(\x0b\x32\".ml_pipelines.ArtifactIteratorSpecH\x00\x12\x41\n\x12parameter_iterator\x18\n \x01(\x0b\x32#.ml_pipelines.ParameterIteratorSpecH\x00\x12@\n\x0cretry_policy\x18\x0b \x01(\x0b\x32*.ml_pipelines.PipelineTaskSpec.RetryPolicy\x12\x46\n\x0fiterator_policy\x18\x0c \x01(\x0b\x32-.ml_pipelines.PipelineTaskSpec.IteratorPolicy\x1a\x39\n\x0e\x43\x61\x63hingOptions\x12\x14\n\x0c\x65nable_cache\x18\x01 \x01(\x08\x12\x11\n\tcache_key\x18\x02 \x01(\t\x1a\xeb\x01\n\rTriggerPolicy\x12\x11\n\tcondition\x18\x01 \x01(\t\x12N\n\x08strategy\x18\x02 \x01(\x0e\x32<.ml_pipelines.PipelineTaskSpec.TriggerPolicy.TriggerStrategy\"w\n\x0fTriggerStrategy\x12 \n\x1cTRIGGER_STRATEGY_UNSPECIFIED\x10\x00\x12 \n\x1c\x41LL_UPSTREAM_TASKS_SUCCEEDED\x10\x01\x12 \n\x1c\x41LL_UPSTREAM_TASKS_COMPLETED\x10\x02\x1a\xac\x01\n\x0bRetryPolicy\x12\x17\n\x0fmax_retry_count\x18\x01 \x01(\x05\x12\x33\n\x10\x62\x61\x63koff_duration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x16\n\x0e\x62\x61\x63koff_factor\x18\x03 \x01(\x01\x12\x37\n\x14\x62\x61\x63koff_max_duration\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x1a+\n\x0eIteratorPolicy\x12\x19\n\x11parallelism_limit\x18\x01 \x01(\x05\x42\n\n\x08iterator\"\x8c\x01\n\x14\x41rtifactIteratorSpec\x12;\n\x05items\x18\x01 \x01(\x0b\x32,.ml_pipelines.ArtifactIteratorSpec.ItemsSpec\x12\x12\n\nitem_input\x18\x02 \x01(\t\x1a#\n\tItemsSpec\x12\x16\n\x0einput_artifact\x18\x01 \x01(\t\"\xa8\x01\n\x15ParameterIteratorSpec\x12<\n\x05items\x18\x01 \x01(\x0b\x32-.ml_pipelines.ParameterIteratorSpec.ItemsSpec\x12\x12\n\nitem_input\x18\x02 \x01(\t\x1a=\n\tItemsSpec\x12\r\n\x03raw\x18\x01 \x01(\tH\x00\x12\x19\n\x0finput_parameter\x18\x02 \x01(\tH\x00\x42\x06\n\x04kind\"\x1c\n\x0c\x43omponentRef\x12\x0c\n\x04name\x18\x01 \x01(\t\"G\n\x0cPipelineInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\"\x81\x01\n\x12\x41rtifactTypeSchema\x12\x16\n\x0cschema_title\x18\x01 \x01(\tH\x00\x12\x18\n\nschema_uri\x18\x02 \x01(\tB\x02\x18\x01H\x00\x12\x19\n\x0finstance_schema\x18\x03 \x01(\tH\x00\x12\x16\n\x0eschema_version\x18\x04 \x01(\tB\x06\n\x04kind\" \n\x10PipelineTaskInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x9e\x01\n\x17ValueOrRuntimeParameter\x12\x31\n\x0e\x63onstant_value\x18\x01 \x01(\x0b\x32\x13.ml_pipelines.ValueB\x02\x18\x01H\x00\x12\x1b\n\x11runtime_parameter\x18\x02 \x01(\tH\x00\x12*\n\x08\x63onstant\x18\x03 \x01(\x0b\x32\x16.google.protobuf.ValueH\x00\x42\x07\n\x05value\"\xf4\x13\n\x18PipelineDeploymentConfig\x12H\n\texecutors\x18\x01 \x03(\x0b\x32\x35.ml_pipelines.PipelineDeploymentConfig.ExecutorsEntry\x1a\xe4\x07\n\x15PipelineContainerSpec\x12\r\n\x05image\x18\x01 \x01(\t\x12\x0f\n\x07\x63ommand\x18\x02 \x03(\t\x12\x0c\n\x04\x61rgs\x18\x03 \x03(\t\x12Y\n\tlifecycle\x18\x04 \x01(\x0b\x32\x46.ml_pipelines.PipelineDeploymentConfig.PipelineContainerSpec.Lifecycle\x12\\\n\tresources\x18\x05 \x01(\x0b\x32I.ml_pipelines.PipelineDeploymentConfig.PipelineContainerSpec.ResourceSpec\x12P\n\x03\x65nv\x18\x06 \x03(\x0b\x32\x43.ml_pipelines.PipelineDeploymentConfig.PipelineContainerSpec.EnvVar\x1a\x98\x01\n\tLifecycle\x12\x64\n\x0fpre_cache_check\x18\x01 \x01(\x0b\x32K.ml_pipelines.PipelineDeploymentConfig.PipelineContainerSpec.Lifecycle.Exec\x1a%\n\x04\x45xec\x12\x0f\n\x07\x63ommand\x18\x02 \x03(\t\x12\x0c\n\x04\x61rgs\x18\x03 \x03(\t\x1a\xcf\x03\n\x0cResourceSpec\x12\x15\n\tcpu_limit\x18\x01 \x01(\x01\x42\x02\x18\x01\x12\x18\n\x0cmemory_limit\x18\x02 \x01(\x01\x42\x02\x18\x01\x12\x17\n\x0b\x63pu_request\x18\x05 \x01(\x01\x42\x02\x18\x01\x12\x1a\n\x0ememory_request\x18\x06 \x01(\x01\x42\x02\x18\x01\x12\x1a\n\x12resource_cpu_limit\x18\x07 \x01(\t\x12\x1d\n\x15resource_memory_limit\x18\x08 \x01(\t\x12\x1c\n\x14resource_cpu_request\x18\t \x01(\t\x12\x1f\n\x17resource_memory_request\x18\n \x01(\t\x12p\n\x0b\x61\x63\x63\x65lerator\x18\x03 \x01(\x0b\x32[.ml_pipelines.PipelineDeploymentConfig.PipelineContainerSpec.ResourceSpec.AcceleratorConfig\x1ag\n\x11\x41\x63\x63\x65leratorConfig\x12\x10\n\x04type\x18\x01 \x01(\tB\x02\x18\x01\x12\x11\n\x05\x63ount\x18\x02 \x01(\x03\x42\x02\x18\x01\x12\x15\n\rresource_type\x18\x03 \x01(\t\x12\x16\n\x0eresource_count\x18\x04 \x01(\tJ\x04\x08\x04\x10\x05\x1a%\n\x06\x45nvVar\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x1a\xdf\x04\n\x0cImporterSpec\x12;\n\x0c\x61rtifact_uri\x18\x01 \x01(\x0b\x32%.ml_pipelines.ValueOrRuntimeParameter\x12\x35\n\x0btype_schema\x18\x02 \x01(\x0b\x32 .ml_pipelines.ArtifactTypeSchema\x12[\n\nproperties\x18\x03 \x03(\x0b\x32\x43.ml_pipelines.PipelineDeploymentConfig.ImporterSpec.PropertiesEntryB\x02\x18\x01\x12h\n\x11\x63ustom_properties\x18\x04 \x03(\x0b\x32I.ml_pipelines.PipelineDeploymentConfig.ImporterSpec.CustomPropertiesEntryB\x02\x18\x01\x12\x10\n\x08reimport\x18\x05 \x01(\x08\x12)\n\x08metadata\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x1d\n\x15\x64ownload_to_workspace\x18\x07 \x01(\x08\x1aX\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x34\n\x05value\x18\x02 \x01(\x0b\x32%.ml_pipelines.ValueOrRuntimeParameter:\x02\x38\x01\x1a^\n\x15\x43ustomPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x34\n\x05value\x18\x02 \x01(\x0b\x32%.ml_pipelines.ValueOrRuntimeParameter:\x02\x38\x01\x1a\xb9\x02\n\x0cResolverSpec\x12o\n\x17output_artifact_queries\x18\x01 \x03(\x0b\x32N.ml_pipelines.PipelineDeploymentConfig.ResolverSpec.OutputArtifactQueriesEntry\x1a\x32\n\x11\x41rtifactQuerySpec\x12\x0e\n\x06\x66ilter\x18\x01 \x01(\t\x12\r\n\x05limit\x18\x02 \x01(\x05\x1a\x83\x01\n\x1aOutputArtifactQueriesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12T\n\x05value\x18\x02 \x01(\x0b\x32\x45.ml_pipelines.PipelineDeploymentConfig.ResolverSpec.ArtifactQuerySpec:\x02\x38\x01\x1aJ\n\x17\x41IPlatformCustomJobSpec\x12+\n\ncustom_job\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct:\x02\x18\x01\x1a\xd5\x02\n\x0c\x45xecutorSpec\x12Q\n\tcontainer\x18\x01 \x01(\x0b\x32<.ml_pipelines.PipelineDeploymentConfig.PipelineContainerSpecH\x00\x12G\n\x08importer\x18\x02 \x01(\x0b\x32\x33.ml_pipelines.PipelineDeploymentConfig.ImporterSpecH\x00\x12G\n\x08resolver\x18\x03 \x01(\x0b\x32\x33.ml_pipelines.PipelineDeploymentConfig.ResolverSpecH\x00\x12X\n\ncustom_job\x18\x04 \x01(\x0b\x32>.ml_pipelines.PipelineDeploymentConfig.AIPlatformCustomJobSpecB\x02\x18\x01H\x00\x42\x06\n\x04spec\x1a\x65\n\x0e\x45xecutorsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x42\n\x05value\x18\x02 \x01(\x0b\x32\x33.ml_pipelines.PipelineDeploymentConfig.ExecutorSpec:\x02\x38\x01\"U\n\x05Value\x12\x13\n\tint_value\x18\x01 \x01(\x03H\x00\x12\x16\n\x0c\x64ouble_value\x18\x02 \x01(\x01H\x00\x12\x16\n\x0cstring_value\x18\x03 \x01(\tH\x00\x42\x07\n\x05value\"\xe2\x03\n\x0fRuntimeArtifact\x12\x0c\n\x04name\x18\x01 \x01(\t\x12.\n\x04type\x18\x02 \x01(\x0b\x32 .ml_pipelines.ArtifactTypeSchema\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x45\n\nproperties\x18\x04 \x03(\x0b\x32-.ml_pipelines.RuntimeArtifact.PropertiesEntryB\x02\x18\x01\x12R\n\x11\x63ustom_properties\x18\x05 \x03(\x0b\x32\x33.ml_pipelines.RuntimeArtifact.CustomPropertiesEntryB\x02\x18\x01\x12)\n\x08metadata\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x18\n\x0b\x63ustom_path\x18\x07 \x01(\tH\x00\x88\x01\x01\x1a\x46\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\"\n\x05value\x18\x02 \x01(\x0b\x32\x13.ml_pipelines.Value:\x02\x38\x01\x1aL\n\x15\x43ustomPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\"\n\x05value\x18\x02 \x01(\x0b\x32\x13.ml_pipelines.Value:\x02\x38\x01\x42\x0e\n\x0c_custom_path\"@\n\x0c\x41rtifactList\x12\x30\n\tartifacts\x18\x01 \x03(\x0b\x32\x1d.ml_pipelines.RuntimeArtifact\"\xd6\x07\n\rExecutorInput\x12\x32\n\x06inputs\x18\x01 \x01(\x0b\x32\".ml_pipelines.ExecutorInput.Inputs\x12\x34\n\x07outputs\x18\x02 \x01(\x0b\x32#.ml_pipelines.ExecutorInput.Outputs\x1a\xd3\x03\n\x06Inputs\x12J\n\nparameters\x18\x01 \x03(\x0b\x32\x32.ml_pipelines.ExecutorInput.Inputs.ParametersEntryB\x02\x18\x01\x12\x44\n\tartifacts\x18\x02 \x03(\x0b\x32\x31.ml_pipelines.ExecutorInput.Inputs.ArtifactsEntry\x12Q\n\x10parameter_values\x18\x03 \x03(\x0b\x32\x37.ml_pipelines.ExecutorInput.Inputs.ParameterValuesEntry\x1a\x46\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\"\n\x05value\x18\x02 \x01(\x0b\x32\x13.ml_pipelines.Value:\x02\x38\x01\x1aL\n\x0e\x41rtifactsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.ml_pipelines.ArtifactList:\x02\x38\x01\x1aN\n\x14ParameterValuesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.Value:\x02\x38\x01\x1a&\n\x0fOutputParameter\x12\x13\n\x0boutput_file\x18\x01 \x01(\t\x1a\xdc\x02\n\x07Outputs\x12G\n\nparameters\x18\x01 \x03(\x0b\x32\x33.ml_pipelines.ExecutorInput.Outputs.ParametersEntry\x12\x45\n\tartifacts\x18\x02 \x03(\x0b\x32\x32.ml_pipelines.ExecutorInput.Outputs.ArtifactsEntry\x12\x13\n\x0boutput_file\x18\x03 \x01(\t\x1a^\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12:\n\x05value\x18\x02 \x01(\x0b\x32+.ml_pipelines.ExecutorInput.OutputParameter:\x02\x38\x01\x1aL\n\x0e\x41rtifactsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.ml_pipelines.ArtifactList:\x02\x38\x01\"\xc9\x03\n\x0e\x45xecutorOutput\x12\x44\n\nparameters\x18\x01 \x03(\x0b\x32,.ml_pipelines.ExecutorOutput.ParametersEntryB\x02\x18\x01\x12>\n\tartifacts\x18\x02 \x03(\x0b\x32+.ml_pipelines.ExecutorOutput.ArtifactsEntry\x12K\n\x10parameter_values\x18\x03 \x03(\x0b\x32\x31.ml_pipelines.ExecutorOutput.ParameterValuesEntry\x1a\x46\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\"\n\x05value\x18\x02 \x01(\x0b\x32\x13.ml_pipelines.Value:\x02\x38\x01\x1aL\n\x0e\x41rtifactsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.ml_pipelines.ArtifactList:\x02\x38\x01\x1aN\n\x14ParameterValuesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.Value:\x02\x38\x01\"\xc9\x01\n\x17PipelineTaskFinalStatus\x12\r\n\x05state\x18\x01 \x01(\t\x12!\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x12.google.rpc.Status\x12\x1d\n\x11pipeline_job_uuid\x18\x03 \x01(\x03\x42\x02\x18\x01\x12\x1d\n\x11pipeline_job_name\x18\x04 \x01(\tB\x02\x18\x01\x12\"\n\x1apipeline_job_resource_name\x18\x05 \x01(\t\x12\x1a\n\x12pipeline_task_name\x18\x06 \x01(\t\"\x9f\x02\n\x11PipelineStateEnum\"\x89\x02\n\x11PipelineTaskState\x12\x1a\n\x16TASK_STATE_UNSPECIFIED\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x12\n\x0eRUNNING_DRIVER\x10\x02\x12\x14\n\x10\x44RIVER_SUCCEEDED\x10\x03\x12\x14\n\x10RUNNING_EXECUTOR\x10\x04\x12\r\n\tSUCCEEDED\x10\x05\x12\x12\n\x0e\x43\x41NCEL_PENDING\x10\x06\x12\x0e\n\nCANCELLING\x10\x07\x12\r\n\tCANCELLED\x10\x08\x12\n\n\x06\x46\x41ILED\x10\t\x12\x0b\n\x07SKIPPED\x10\n\x12\n\n\x06QUEUED\x10\x0b\x12\x11\n\rNOT_TRIGGERED\x10\x0c\x12\x11\n\rUNSCHEDULABLE\x10\r\"\xa0\x01\n\x0cPlatformSpec\x12<\n\tplatforms\x18\x01 \x03(\x0b\x32).ml_pipelines.PlatformSpec.PlatformsEntry\x1aR\n\x0ePlatformsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12/\n\x05value\x18\x02 \x01(\x0b\x32 .ml_pipelines.SinglePlatformSpec:\x02\x38\x01\"\xc6\x01\n\x12SinglePlatformSpec\x12?\n\x0f\x64\x65ployment_spec\x18\x01 \x01(\x0b\x32&.ml_pipelines.PlatformDeploymentConfig\x12\x10\n\x08platform\x18\x02 \x01(\t\x12\'\n\x06\x63onfig\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x34\n\x0epipelineConfig\x18\x04 \x01(\x0b\x32\x1c.ml_pipelines.PipelineConfig\"\xaf\x01\n\x18PlatformDeploymentConfig\x12H\n\texecutors\x18\x01 \x03(\x0b\x32\x35.ml_pipelines.PlatformDeploymentConfig.ExecutorsEntry\x1aI\n\x0e\x45xecutorsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct:\x02\x38\x01\"p\n\x0fWorkspaceConfig\x12\x0c\n\x04size\x18\x01 \x01(\t\x12@\n\nkubernetes\x18\x02 \x01(\x0b\x32\'.ml_pipelines.KubernetesWorkspaceConfigH\x00\x88\x01\x01\x42\r\n\x0b_kubernetes\"d\n\x19KubernetesWorkspaceConfig\x12\x34\n\x0epvc_spec_patch\x18\x01 \x01(\x0b\x32\x17.google.protobuf.StructH\x00\x88\x01\x01\x42\x11\n\x0f_pvc_spec_patch\"k\n\x0ePipelineConfig\x12\x14\n\x0cresource_ttl\x18\x01 \x01(\x05\x12\x35\n\tworkspace\x18\x02 \x01(\x0b\x32\x1d.ml_pipelines.WorkspaceConfigH\x00\x88\x01\x01\x42\x0c\n\n_workspaceB<Z:github.com/kubeflow/pipelines/api/v2alpha1/go/pipelinespecb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'pipeline_spec_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z:github.com/kubeflow/pipelines/api/v2alpha1/go/pipelinespec'
  _globals['_PIPELINEJOB_LABELSENTRY']._loaded_options = None
  _globals['_PIPELINEJOB_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_PIPELINEJOB_RUNTIMECONFIG_PARAMETERSENTRY']._loaded_options = None
  _globals['_PIPELINEJOB_RUNTIMECONFIG_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_PIPELINEJOB_RUNTIMECONFIG_PARAMETERVALUESENTRY']._loaded_options = None
  _globals['_PIPELINEJOB_RUNTIMECONFIG_PARAMETERVALUESENTRY']._serialized_options = b'8\001'
  _globals['_PIPELINEJOB_RUNTIMECONFIG'].fields_by_name['parameters']._loaded_options = None
  _globals['_PIPELINEJOB_RUNTIMECONFIG'].fields_by_name['parameters']._serialized_options = b'\030\001'
  _globals['_PIPELINESPEC_COMPONENTSENTRY']._loaded_options = None
  _globals['_PIPELINESPEC_COMPONENTSENTRY']._serialized_options = b'8\001'
  _globals['_DAGSPEC_TASKSENTRY']._loaded_options = None
  _globals['_DAGSPEC_TASKSENTRY']._serialized_options = b'8\001'
  _globals['_DAGOUTPUTSSPEC_ARTIFACTSENTRY']._loaded_options = None
  _globals['_DAGOUTPUTSSPEC_ARTIFACTSENTRY']._serialized_options = b'8\001'
  _globals['_DAGOUTPUTSSPEC_MAPPARAMETERSELECTORSSPEC_MAPPEDPARAMETERSENTRY']._loaded_options = None
  _globals['_DAGOUTPUTSSPEC_MAPPARAMETERSELECTORSSPEC_MAPPEDPARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_DAGOUTPUTSSPEC_PARAMETERSENTRY']._loaded_options = None
  _globals['_DAGOUTPUTSSPEC_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_COMPONENTINPUTSSPEC_PARAMETERSPEC'].fields_by_name['type']._loaded_options = None
  _globals['_COMPONENTINPUTSSPEC_PARAMETERSPEC'].fields_by_name['type']._serialized_options = b'\030\001'
  _globals['_COMPONENTINPUTSSPEC_ARTIFACTSENTRY']._loaded_options = None
  _globals['_COMPONENTINPUTSSPEC_ARTIFACTSENTRY']._serialized_options = b'8\001'
  _globals['_COMPONENTINPUTSSPEC_PARAMETERSENTRY']._loaded_options = None
  _globals['_COMPONENTINPUTSSPEC_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_COMPONENTOUTPUTSSPEC_ARTIFACTSPEC_PROPERTIESENTRY']._loaded_options = None
  _globals['_COMPONENTOUTPUTSSPEC_ARTIFACTSPEC_PROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_COMPONENTOUTPUTSSPEC_ARTIFACTSPEC_CUSTOMPROPERTIESENTRY']._loaded_options = None
  _globals['_COMPONENTOUTPUTSSPEC_ARTIFACTSPEC_CUSTOMPROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_COMPONENTOUTPUTSSPEC_ARTIFACTSPEC'].fields_by_name['properties']._loaded_options = None
  _globals['_COMPONENTOUTPUTSSPEC_ARTIFACTSPEC'].fields_by_name['properties']._serialized_options = b'\030\001'
  _globals['_COMPONENTOUTPUTSSPEC_ARTIFACTSPEC'].fields_by_name['custom_properties']._loaded_options = None
  _globals['_COMPONENTOUTPUTSSPEC_ARTIFACTSPEC'].fields_by_name['custom_properties']._serialized_options = b'\030\001'
  _globals['_COMPONENTOUTPUTSSPEC_PARAMETERSPEC'].fields_by_name['type']._loaded_options = None
  _globals['_COMPONENTOUTPUTSSPEC_PARAMETERSPEC'].fields_by_name['type']._serialized_options = b'\030\001'
  _globals['_COMPONENTOUTPUTSSPEC_ARTIFACTSENTRY']._loaded_options = None
  _globals['_COMPONENTOUTPUTSSPEC_ARTIFACTSENTRY']._serialized_options = b'8\001'
  _globals['_COMPONENTOUTPUTSSPEC_PARAMETERSENTRY']._loaded_options = None
  _globals['_COMPONENTOUTPUTSSPEC_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_TASKINPUTSSPEC_PARAMETERSENTRY']._loaded_options = None
  _globals['_TASKINPUTSSPEC_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_TASKINPUTSSPEC_ARTIFACTSENTRY']._loaded_options = None
  _globals['_TASKINPUTSSPEC_ARTIFACTSENTRY']._serialized_options = b'8\001'
  _globals['_TASKOUTPUTSSPEC_OUTPUTARTIFACTSPEC_PROPERTIESENTRY']._loaded_options = None
  _globals['_TASKOUTPUTSSPEC_OUTPUTARTIFACTSPEC_PROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_TASKOUTPUTSSPEC_OUTPUTARTIFACTSPEC_CUSTOMPROPERTIESENTRY']._loaded_options = None
  _globals['_TASKOUTPUTSSPEC_OUTPUTARTIFACTSPEC_CUSTOMPROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_TASKOUTPUTSSPEC_PARAMETERSENTRY']._loaded_options = None
  _globals['_TASKOUTPUTSSPEC_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_TASKOUTPUTSSPEC_ARTIFACTSENTRY']._loaded_options = None
  _globals['_TASKOUTPUTSSPEC_ARTIFACTSENTRY']._serialized_options = b'8\001'
  _globals['_PRIMITIVETYPE_PRIMITIVETYPEENUM']._loaded_options = None
  _globals['_PRIMITIVETYPE_PRIMITIVETYPEENUM']._serialized_options = b'\030\001'
  _globals['_PRIMITIVETYPE']._loaded_options = None
  _globals['_PRIMITIVETYPE']._serialized_options = b'\030\001'
  _globals['_ARTIFACTTYPESCHEMA'].fields_by_name['schema_uri']._loaded_options = None
  _globals['_ARTIFACTTYPESCHEMA'].fields_by_name['schema_uri']._serialized_options = b'\030\001'
  _globals['_VALUEORRUNTIMEPARAMETER'].fields_by_name['constant_value']._loaded_options = None
  _globals['_VALUEORRUNTIMEPARAMETER'].fields_by_name['constant_value']._serialized_options = b'\030\001'
  _globals['_PIPELINEDEPLOYMENTCONFIG_PIPELINECONTAINERSPEC_RESOURCESPEC_ACCELERATORCONFIG'].fields_by_name['type']._loaded_options = None
  _globals['_PIPELINEDEPLOYMENTCONFIG_PIPELINECONTAINERSPEC_RESOURCESPEC_ACCELERATORCONFIG'].fields_by_name['type']._serialized_options = b'\030\001'
  _globals['_PIPELINEDEPLOYMENTCONFIG_PIPELINECONTAINERSPEC_RESOURCESPEC_ACCELERATORCONFIG'].fields_by_name['count']._loaded_options = None
  _globals['_PIPELINEDEPLOYMENTCONFIG_PIPELINECONTAINERSPEC_RESOURCESPEC_ACCELERATORCONFIG'].fields_by_name['count']._serialized_options = b'\030\001'
  _globals['_PIPELINEDEPLOYMENTCONFIG_PIPELINECONTAINERSPEC_RESOURCESPEC'].fields_by_name['cpu_limit']._loaded_options = None
  _globals['_PIPELINEDEPLOYMENTCONFIG_PIPELINECONTAINERSPEC_RESOURCESPEC'].fields_by_name['cpu_limit']._serialized_options = b'\030\001'
  _globals['_PIPELINEDEPLOYMENTCONFIG_PIPELINECONTAINERSPEC_RESOURCESPEC'].fields_by_name['memory_limit']._loaded_options = None
  _globals['_PIPELINEDEPLOYMENTCONFIG_PIPELINECONTAINERSPEC_RESOURCESPEC'].fields_by_name['memory_limit']._serialized_options = b'\030\001'
  _globals['_PIPELINEDEPLOYMENTCONFIG_PIPELINECONTAINERSPEC_RESOURCESPEC'].fields_by_name['cpu_request']._loaded_options = None
  _globals['_PIPELINEDEPLOYMENTCONFIG_PIPELINECONTAINERSPEC_RESOURCESPEC'].fields_by_name['cpu_request']._serialized_options = b'\030\001'
  _globals['_PIPELINEDEPLOYMENTCONFIG_PIPELINECONTAINERSPEC_RESOURCESPEC'].fields_by_name['memory_request']._loaded_options = None
  _globals['_PIPELINEDEPLOYMENTCONFIG_PIPELINECONTAINERSPEC_RESOURCESPEC'].fields_by_name['memory_request']._serialized_options = b'\030\001'
  _globals['_PIPELINEDEPLOYMENTCONFIG_IMPORTERSPEC_PROPERTIESENTRY']._loaded_options = None
  _globals['_PIPELINEDEPLOYMENTCONFIG_IMPORTERSPEC_PROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_PIPELINEDEPLOYMENTCONFIG_IMPORTERSPEC_CUSTOMPROPERTIESENTRY']._loaded_options = None
  _globals['_PIPELINEDEPLOYMENTCONFIG_IMPORTERSPEC_CUSTOMPROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_PIPELINEDEPLOYMENTCONFIG_IMPORTERSPEC'].fields_by_name['properties']._loaded_options = None
  _globals['_PIPELINEDEPLOYMENTCONFIG_IMPORTERSPEC'].fields_by_name['properties']._serialized_options = b'\030\001'
  _globals['_PIPELINEDEPLOYMENTCONFIG_IMPORTERSPEC'].fields_by_name['custom_properties']._loaded_options = None
  _globals['_PIPELINEDEPLOYMENTCONFIG_IMPORTERSPEC'].fields_by_name['custom_properties']._serialized_options = b'\030\001'
  _globals['_PIPELINEDEPLOYMENTCONFIG_RESOLVERSPEC_OUTPUTARTIFACTQUERIESENTRY']._loaded_options = None
  _globals['_PIPELINEDEPLOYMENTCONFIG_RESOLVERSPEC_OUTPUTARTIFACTQUERIESENTRY']._serialized_options = b'8\001'
  _globals['_PIPELINEDEPLOYMENTCONFIG_AIPLATFORMCUSTOMJOBSPEC']._loaded_options = None
  _globals['_PIPELINEDEPLOYMENTCONFIG_AIPLATFORMCUSTOMJOBSPEC']._serialized_options = b'\030\001'
  _globals['_PIPELINEDEPLOYMENTCONFIG_EXECUTORSPEC'].fields_by_name['custom_job']._loaded_options = None
  _globals['_PIPELINEDEPLOYMENTCONFIG_EXECUTORSPEC'].fields_by_name['custom_job']._serialized_options = b'\030\001'
  _globals['_PIPELINEDEPLOYMENTCONFIG_EXECUTORSENTRY']._loaded_options = None
  _globals['_PIPELINEDEPLOYMENTCONFIG_EXECUTORSENTRY']._serialized_options = b'8\001'
  _globals['_RUNTIMEARTIFACT_PROPERTIESENTRY']._loaded_options = None
  _globals['_RUNTIMEARTIFACT_PROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_RUNTIMEARTIFACT_CUSTOMPROPERTIESENTRY']._loaded_options = None
  _globals['_RUNTIMEARTIFACT_CUSTOMPROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_RUNTIMEARTIFACT'].fields_by_name['properties']._loaded_options = None
  _globals['_RUNTIMEARTIFACT'].fields_by_name['properties']._serialized_options = b'\030\001'
  _globals['_RUNTIMEARTIFACT'].fields_by_name['custom_properties']._loaded_options = None
  _globals['_RUNTIMEARTIFACT'].fields_by_name['custom_properties']._serialized_options = b'\030\001'
  _globals['_EXECUTORINPUT_INPUTS_PARAMETERSENTRY']._loaded_options = None
  _globals['_EXECUTORINPUT_INPUTS_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_EXECUTORINPUT_INPUTS_ARTIFACTSENTRY']._loaded_options = None
  _globals['_EXECUTORINPUT_INPUTS_ARTIFACTSENTRY']._serialized_options = b'8\001'
  _globals['_EXECUTORINPUT_INPUTS_PARAMETERVALUESENTRY']._loaded_options = None
  _globals['_EXECUTORINPUT_INPUTS_PARAMETERVALUESENTRY']._serialized_options = b'8\001'
  _globals['_EXECUTORINPUT_INPUTS'].fields_by_name['parameters']._loaded_options = None
  _globals['_EXECUTORINPUT_INPUTS'].fields_by_name['parameters']._serialized_options = b'\030\001'
  _globals['_EXECUTORINPUT_OUTPUTS_PARAMETERSENTRY']._loaded_options = None
  _globals['_EXECUTORINPUT_OUTPUTS_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_EXECUTORINPUT_OUTPUTS_ARTIFACTSENTRY']._loaded_options = None
  _globals['_EXECUTORINPUT_OUTPUTS_ARTIFACTSENTRY']._serialized_options = b'8\001'
  _globals['_EXECUTOROUTPUT_PARAMETERSENTRY']._loaded_options = None
  _globals['_EXECUTOROUTPUT_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_EXECUTOROUTPUT_ARTIFACTSENTRY']._loaded_options = None
  _globals['_EXECUTOROUTPUT_ARTIFACTSENTRY']._serialized_options = b'8\001'
  _globals['_EXECUTOROUTPUT_PARAMETERVALUESENTRY']._loaded_options = None
  _globals['_EXECUTOROUTPUT_PARAMETERVALUESENTRY']._serialized_options = b'8\001'
  _globals['_EXECUTOROUTPUT'].fields_by_name['parameters']._loaded_options = None
  _globals['_EXECUTOROUTPUT'].fields_by_name['parameters']._serialized_options = b'\030\001'
  _globals['_PIPELINETASKFINALSTATUS'].fields_by_name['pipeline_job_uuid']._loaded_options = None
  _globals['_PIPELINETASKFINALSTATUS'].fields_by_name['pipeline_job_uuid']._serialized_options = b'\030\001'
  _globals['_PIPELINETASKFINALSTATUS'].fields_by_name['pipeline_job_name']._loaded_options = None
  _globals['_PIPELINETASKFINALSTATUS'].fields_by_name['pipeline_job_name']._serialized_options = b'\030\001'
  _globals['_PLATFORMSPEC_PLATFORMSENTRY']._loaded_options = None
  _globals['_PLATFORMSPEC_PLATFORMSENTRY']._serialized_options = b'8\001'
  _globals['_PLATFORMDEPLOYMENTCONFIG_EXECUTORSENTRY']._loaded_options = None
  _globals['_PLATFORMDEPLOYMENTCONFIG_EXECUTORSENTRY']._serialized_options = b'8\001'
  _globals['_PIPELINEJOB']._serialized_start=125
  _globals['_PIPELINEJOB']._serialized_end=800
  _globals['_PIPELINEJOB_LABELSENTRY']._serialized_start=344
  _globals['_PIPELINEJOB_LABELSENTRY']._serialized_end=389
  _globals['_PIPELINEJOB_RUNTIMECONFIG']._serialized_start=392
  _globals['_PIPELINEJOB_RUNTIMECONFIG']._serialized_end=758
  _globals['_PIPELINEJOB_RUNTIMECONFIG_PARAMETERSENTRY']._serialized_start=608
  _globals['_PIPELINEJOB_RUNTIMECONFIG_PARAMETERSENTRY']._serialized_end=678
  _globals['_PIPELINEJOB_RUNTIMECONFIG_PARAMETERVALUESENTRY']._serialized_start=680
  _globals['_PIPELINEJOB_RUNTIMECONFIG_PARAMETERVALUESENTRY']._serialized_end=758
  _globals['_PIPELINESPEC']._serialized_start=803
  _globals['_PIPELINESPEC']._serialized_end=1306
  _globals['_PIPELINESPEC_RUNTIMEPARAMETER']._serialized_start=1103
  _globals['_PIPELINESPEC_RUNTIMEPARAMETER']._serialized_end=1226
  _globals['_PIPELINESPEC_COMPONENTSENTRY']._serialized_start=1228
  _globals['_PIPELINESPEC_COMPONENTSENTRY']._serialized_end=1306
  _globals['_COMPONENTSPEC']._serialized_start=1309
  _globals['_COMPONENTSPEC']._serialized_end=1668
  _globals['_DAGSPEC']._serialized_start=1671
  _globals['_DAGSPEC']._serialized_end=1854
  _globals['_DAGSPEC_TASKSENTRY']._serialized_start=1778
  _globals['_DAGSPEC_TASKSENTRY']._serialized_end=1854
  _globals['_DAGOUTPUTSSPEC']._serialized_start=1857
  _globals['_DAGOUTPUTSSPEC']._serialized_end=3030
  _globals['_DAGOUTPUTSSPEC_ARTIFACTSELECTORSPEC']._serialized_start=2005
  _globals['_DAGOUTPUTSSPEC_ARTIFACTSELECTORSPEC']._serialized_end=2082
  _globals['_DAGOUTPUTSSPEC_DAGOUTPUTARTIFACTSPEC']._serialized_start=2084
  _globals['_DAGOUTPUTSSPEC_DAGOUTPUTARTIFACTSPEC']._serialized_end=2186
  _globals['_DAGOUTPUTSSPEC_ARTIFACTSENTRY']._serialized_start=2188
  _globals['_DAGOUTPUTSSPEC_ARTIFACTSENTRY']._serialized_end=2288
  _globals['_DAGOUTPUTSSPEC_PARAMETERSELECTORSPEC']._serialized_start=2290
  _globals['_DAGOUTPUTSSPEC_PARAMETERSELECTORSPEC']._serialized_end=2369
  _globals['_DAGOUTPUTSSPEC_PARAMETERSELECTORSSPEC']._serialized_start=2371
  _globals['_DAGOUTPUTSSPEC_PARAMETERSELECTORSSPEC']._serialized_end=2476
  _globals['_DAGOUTPUTSSPEC_MAPPARAMETERSELECTORSSPEC']._serialized_start=2479
  _globals['_DAGOUTPUTSSPEC_MAPPARAMETERSELECTORSSPEC']._serialized_end=2720
  _globals['_DAGOUTPUTSSPEC_MAPPARAMETERSELECTORSSPEC_MAPPEDPARAMETERSENTRY']._serialized_start=2613
  _globals['_DAGOUTPUTSSPEC_MAPPARAMETERSELECTORSSPEC_MAPPEDPARAMETERSENTRY']._serialized_end=2720
  _globals['_DAGOUTPUTSSPEC_DAGOUTPUTPARAMETERSPEC']._serialized_start=2723
  _globals['_DAGOUTPUTSSPEC_DAGOUTPUTPARAMETERSPEC']._serialized_end=2926
  _globals['_DAGOUTPUTSSPEC_PARAMETERSENTRY']._serialized_start=2928
  _globals['_DAGOUTPUTSSPEC_PARAMETERSENTRY']._serialized_end=3030
  _globals['_COMPONENTINPUTSSPEC']._serialized_start=3033
  _globals['_COMPONENTINPUTSSPEC']._serialized_end=3777
  _globals['_COMPONENTINPUTSSPEC_ARTIFACTSPEC']._serialized_start=3197
  _globals['_COMPONENTINPUTSSPEC_ARTIFACTSPEC']._serialized_end=3336
  _globals['_COMPONENTINPUTSSPEC_PARAMETERSPEC']._serialized_start=3339
  _globals['_COMPONENTINPUTSSPEC_PARAMETERSPEC']._serialized_end=3579
  _globals['_COMPONENTINPUTSSPEC_ARTIFACTSENTRY']._serialized_start=3581
  _globals['_COMPONENTINPUTSSPEC_ARTIFACTSENTRY']._serialized_end=3677
  _globals['_COMPONENTINPUTSSPEC_PARAMETERSENTRY']._serialized_start=3679
  _globals['_COMPONENTINPUTSSPEC_PARAMETERSENTRY']._serialized_end=3777
  _globals['_COMPONENTOUTPUTSSPEC']._serialized_start=3780
  _globals['_COMPONENTOUTPUTSSPEC']._serialized_end=4860
  _globals['_COMPONENTOUTPUTSSPEC_ARTIFACTSPEC']._serialized_start=3947
  _globals['_COMPONENTOUTPUTSSPEC_ARTIFACTSPEC']._serialized_end=4485
  _globals['_COMPONENTOUTPUTSSPEC_ARTIFACTSPEC_PROPERTIESENTRY']._serialized_start=4301
  _globals['_COMPONENTOUTPUTSSPEC_ARTIFACTSPEC_PROPERTIESENTRY']._serialized_end=4389
  _globals['_COMPONENTOUTPUTSSPEC_ARTIFACTSPEC_CUSTOMPROPERTIESENTRY']._serialized_start=4391
  _globals['_COMPONENTOUTPUTSSPEC_ARTIFACTSPEC_CUSTOMPROPERTIESENTRY']._serialized_end=4485
  _globals['_COMPONENTOUTPUTSSPEC_PARAMETERSPEC']._serialized_start=4488
  _globals['_COMPONENTOUTPUTSSPEC_PARAMETERSPEC']._serialized_end=4660
  _globals['_COMPONENTOUTPUTSSPEC_ARTIFACTSENTRY']._serialized_start=4662
  _globals['_COMPONENTOUTPUTSSPEC_ARTIFACTSENTRY']._serialized_end=4759
  _globals['_COMPONENTOUTPUTSSPEC_PARAMETERSENTRY']._serialized_start=4761
  _globals['_COMPONENTOUTPUTSSPEC_PARAMETERSENTRY']._serialized_end=4860
  _globals['_TASKINPUTSSPEC']._serialized_start=4863
  _globals['_TASKINPUTSSPEC']._serialized_end=5953
  _globals['_TASKINPUTSSPEC_INPUTARTIFACTSPEC']._serialized_start=5012
  _globals['_TASKINPUTSSPEC_INPUTARTIFACTSPEC']._serialized_end=5262
  _globals['_TASKINPUTSSPEC_INPUTARTIFACTSPEC_TASKOUTPUTARTIFACTSPEC']._serialized_start=5172
  _globals['_TASKINPUTSSPEC_INPUTARTIFACTSPEC_TASKOUTPUTARTIFACTSPEC']._serialized_end=5248
  _globals['_TASKINPUTSSPEC_INPUTPARAMETERSPEC']._serialized_start=5265
  _globals['_TASKINPUTSSPEC_INPUTPARAMETERSPEC']._serialized_end=5755
  _globals['_TASKINPUTSSPEC_INPUTPARAMETERSPEC_TASKOUTPUTPARAMETERSPEC']._serialized_start=5627
  _globals['_TASKINPUTSSPEC_INPUTPARAMETERSPEC_TASKOUTPUTPARAMETERSPEC']._serialized_end=5705
  _globals['_TASKINPUTSSPEC_INPUTPARAMETERSPEC_TASKFINALSTATUS']._serialized_start=5707
  _globals['_TASKINPUTSSPEC_INPUTPARAMETERSPEC_TASKFINALSTATUS']._serialized_end=5747
  _globals['_TASKINPUTSSPEC_PARAMETERSENTRY']._serialized_start=5757
  _globals['_TASKINPUTSSPEC_PARAMETERSENTRY']._serialized_end=5855
  _globals['_TASKINPUTSSPEC_ARTIFACTSENTRY']._serialized_start=5857
  _globals['_TASKINPUTSSPEC_ARTIFACTSENTRY']._serialized_end=5953
  _globals['_TASKOUTPUTSSPEC']._serialized_start=5956
  _globals['_TASKOUTPUTSSPEC']._serialized_end=6842
  _globals['_TASKOUTPUTSSPEC_OUTPUTARTIFACTSPEC']._serialized_start=6108
  _globals['_TASKOUTPUTSSPEC_OUTPUTARTIFACTSPEC']._serialized_end=6556
  _globals['_TASKOUTPUTSSPEC_OUTPUTARTIFACTSPEC_PROPERTIESENTRY']._serialized_start=4301
  _globals['_TASKOUTPUTSSPEC_OUTPUTARTIFACTSPEC_PROPERTIESENTRY']._serialized_end=4389
  _globals['_TASKOUTPUTSSPEC_OUTPUTARTIFACTSPEC_CUSTOMPROPERTIESENTRY']._serialized_start=4391
  _globals['_TASKOUTPUTSSPEC_OUTPUTARTIFACTSPEC_CUSTOMPROPERTIESENTRY']._serialized_end=4485
  _globals['_TASKOUTPUTSSPEC_OUTPUTPARAMETERSPEC']._serialized_start=6558
  _globals['_TASKOUTPUTSSPEC_OUTPUTPARAMETERSPEC']._serialized_end=6640
  _globals['_TASKOUTPUTSSPEC_PARAMETERSENTRY']._serialized_start=6642
  _globals['_TASKOUTPUTSSPEC_PARAMETERSENTRY']._serialized_end=6742
  _globals['_TASKOUTPUTSSPEC_ARTIFACTSENTRY']._serialized_start=6744
  _globals['_TASKOUTPUTSSPEC_ARTIFACTSENTRY']._serialized_end=6842
  _globals['_PRIMITIVETYPE']._serialized_start=6844
  _globals['_PRIMITIVETYPE']._serialized_end=6953
  _globals['_PRIMITIVETYPE_PRIMITIVETYPEENUM']._serialized_start=6861
  _globals['_PRIMITIVETYPE_PRIMITIVETYPEENUM']._serialized_end=6949
  _globals['_PARAMETERTYPE']._serialized_start=6956
  _globals['_PARAMETERTYPE']._serialized_end=7156
  _globals['_PARAMETERTYPE_PARAMETERTYPEENUM']._serialized_start=6974
  _globals['_PARAMETERTYPE_PARAMETERTYPEENUM']._serialized_end=7156
  _globals['_TASKCONFIGPASSTHROUGHTYPE']._serialized_start=7159
  _globals['_TASKCONFIGPASSTHROUGHTYPE']._serialized_end=7361
  _globals['_TASKCONFIGPASSTHROUGHTYPE_TASKCONFIGPASSTHROUGHTYPEENUM']._serialized_start=7189
  _globals['_TASKCONFIGPASSTHROUGHTYPE_TASKCONFIGPASSTHROUGHTYPEENUM']._serialized_end=7361
  _globals['_TASKCONFIGPASSTHROUGH']._serialized_start=7364
  _globals['_TASKCONFIGPASSTHROUGH']._serialized_end=7496
  _globals['_PIPELINETASKSPEC']._serialized_start=7499
  _globals['_PIPELINETASKSPEC']._serialized_end=8631
  _globals['_PIPELINETASKSPEC_CACHINGOPTIONS']._serialized_start=8104
  _globals['_PIPELINETASKSPEC_CACHINGOPTIONS']._serialized_end=8161
  _globals['_PIPELINETASKSPEC_TRIGGERPOLICY']._serialized_start=8164
  _globals['_PIPELINETASKSPEC_TRIGGERPOLICY']._serialized_end=8399
  _globals['_PIPELINETASKSPEC_TRIGGERPOLICY_TRIGGERSTRATEGY']._serialized_start=8280
  _globals['_PIPELINETASKSPEC_TRIGGERPOLICY_TRIGGERSTRATEGY']._serialized_end=8399
  _globals['_PIPELINETASKSPEC_RETRYPOLICY']._serialized_start=8402
  _globals['_PIPELINETASKSPEC_RETRYPOLICY']._serialized_end=8574
  _globals['_PIPELINETASKSPEC_ITERATORPOLICY']._serialized_start=8576
  _globals['_PIPELINETASKSPEC_ITERATORPOLICY']._serialized_end=8619
  _globals['_ARTIFACTITERATORSPEC']._serialized_start=8634
  _globals['_ARTIFACTITERATORSPEC']._serialized_end=8774
  _globals['_ARTIFACTITERATORSPEC_ITEMSSPEC']._serialized_start=8739
  _globals['_ARTIFACTITERATORSPEC_ITEMSSPEC']._serialized_end=8774
  _globals['_PARAMETERITERATORSPEC']._serialized_start=8777
  _globals['_PARAMETERITERATORSPEC']._serialized_end=8945
  _globals['_PARAMETERITERATORSPEC_ITEMSSPEC']._serialized_start=8884
  _globals['_PARAMETERITERATORSPEC_ITEMSSPEC']._serialized_end=8945
  _globals['_COMPONENTREF']._serialized_start=8947
  _globals['_COMPONENTREF']._serialized_end=8975
  _globals['_PIPELINEINFO']._serialized_start=8977
  _globals['_PIPELINEINFO']._serialized_end=9048
  _globals['_ARTIFACTTYPESCHEMA']._serialized_start=9051
  _globals['_ARTIFACTTYPESCHEMA']._serialized_end=9180
  _globals['_PIPELINETASKINFO']._serialized_start=9182
  _globals['_PIPELINETASKINFO']._serialized_end=9214
  _globals['_VALUEORRUNTIMEPARAMETER']._serialized_start=9217
  _globals['_VALUEORRUNTIMEPARAMETER']._serialized_end=9375
  _globals['_PIPELINEDEPLOYMENTCONFIG']._serialized_start=9378
  _globals['_PIPELINEDEPLOYMENTCONFIG']._serialized_end=11926
  _globals['_PIPELINEDEPLOYMENTCONFIG_PIPELINECONTAINERSPEC']._serialized_start=9481
  _globals['_PIPELINEDEPLOYMENTCONFIG_PIPELINECONTAINERSPEC']._serialized_end=10477
  _globals['_PIPELINEDEPLOYMENTCONFIG_PIPELINECONTAINERSPEC_LIFECYCLE']._serialized_start=9820
  _globals['_PIPELINEDEPLOYMENTCONFIG_PIPELINECONTAINERSPEC_LIFECYCLE']._serialized_end=9972
  _globals['_PIPELINEDEPLOYMENTCONFIG_PIPELINECONTAINERSPEC_LIFECYCLE_EXEC']._serialized_start=9935
  _globals['_PIPELINEDEPLOYMENTCONFIG_PIPELINECONTAINERSPEC_LIFECYCLE_EXEC']._serialized_end=9972
  _globals['_PIPELINEDEPLOYMENTCONFIG_PIPELINECONTAINERSPEC_RESOURCESPEC']._serialized_start=9975
  _globals['_PIPELINEDEPLOYMENTCONFIG_PIPELINECONTAINERSPEC_RESOURCESPEC']._serialized_end=10438
  _globals['_PIPELINEDEPLOYMENTCONFIG_PIPELINECONTAINERSPEC_RESOURCESPEC_ACCELERATORCONFIG']._serialized_start=10329
  _globals['_PIPELINEDEPLOYMENTCONFIG_PIPELINECONTAINERSPEC_RESOURCESPEC_ACCELERATORCONFIG']._serialized_end=10432
  _globals['_PIPELINEDEPLOYMENTCONFIG_PIPELINECONTAINERSPEC_ENVVAR']._serialized_start=10440
  _globals['_PIPELINEDEPLOYMENTCONFIG_PIPELINECONTAINERSPEC_ENVVAR']._serialized_end=10477
  _globals['_PIPELINEDEPLOYMENTCONFIG_IMPORTERSPEC']._serialized_start=10480
  _globals['_PIPELINEDEPLOYMENTCONFIG_IMPORTERSPEC']._serialized_end=11087
  _globals['_PIPELINEDEPLOYMENTCONFIG_IMPORTERSPEC_PROPERTIESENTRY']._serialized_start=4301
  _globals['_PIPELINEDEPLOYMENTCONFIG_IMPORTERSPEC_PROPERTIESENTRY']._serialized_end=4389
  _globals['_PIPELINEDEPLOYMENTCONFIG_IMPORTERSPEC_CUSTOMPROPERTIESENTRY']._serialized_start=4391
  _globals['_PIPELINEDEPLOYMENTCONFIG_IMPORTERSPEC_CUSTOMPROPERTIESENTRY']._serialized_end=4485
  _globals['_PIPELINEDEPLOYMENTCONFIG_RESOLVERSPEC']._serialized_start=11090
  _globals['_PIPELINEDEPLOYMENTCONFIG_RESOLVERSPEC']._serialized_end=11403
  _globals['_PIPELINEDEPLOYMENTCONFIG_RESOLVERSPEC_ARTIFACTQUERYSPEC']._serialized_start=11219
  _globals['_PIPELINEDEPLOYMENTCONFIG_RESOLVERSPEC_ARTIFACTQUERYSPEC']._serialized_end=11269
  _globals['_PIPELINEDEPLOYMENTCONFIG_RESOLVERSPEC_OUTPUTARTIFACTQUERIESENTRY']._serialized_start=11272
  _globals['_PIPELINEDEPLOYMENTCONFIG_RESOLVERSPEC_OUTPUTARTIFACTQUERIESENTRY']._serialized_end=11403
  _globals['_PIPELINEDEPLOYMENTCONFIG_AIPLATFORMCUSTOMJOBSPEC']._serialized_start=11405
  _globals['_PIPELINEDEPLOYMENTCONFIG_AIPLATFORMCUSTOMJOBSPEC']._serialized_end=11479
  _globals['_PIPELINEDEPLOYMENTCONFIG_EXECUTORSPEC']._serialized_start=11482
  _globals['_PIPELINEDEPLOYMENTCONFIG_EXECUTORSPEC']._serialized_end=11823
  _globals['_PIPELINEDEPLOYMENTCONFIG_EXECUTORSENTRY']._serialized_start=11825
  _globals['_PIPELINEDEPLOYMENTCONFIG_EXECUTORSENTRY']._serialized_end=11926
  _globals['_VALUE']._serialized_start=11928
  _globals['_VALUE']._serialized_end=12013
  _globals['_RUNTIMEARTIFACT']._serialized_start=12016
  _globals['_RUNTIMEARTIFACT']._serialized_end=12498
  _globals['_RUNTIMEARTIFACT_PROPERTIESENTRY']._serialized_start=12334
  _globals['_RUNTIMEARTIFACT_PROPERTIESENTRY']._serialized_end=12404
  _globals['_RUNTIMEARTIFACT_CUSTOMPROPERTIESENTRY']._serialized_start=12406
  _globals['_RUNTIMEARTIFACT_CUSTOMPROPERTIESENTRY']._serialized_end=12482
  _globals['_ARTIFACTLIST']._serialized_start=12500
  _globals['_ARTIFACTLIST']._serialized_end=12564
  _globals['_EXECUTORINPUT']._serialized_start=12567
  _globals['_EXECUTORINPUT']._serialized_end=13549
  _globals['_EXECUTORINPUT_INPUTS']._serialized_start=12691
  _globals['_EXECUTORINPUT_INPUTS']._serialized_end=13158
  _globals['_EXECUTORINPUT_INPUTS_PARAMETERSENTRY']._serialized_start=608
  _globals['_EXECUTORINPUT_INPUTS_PARAMETERSENTRY']._serialized_end=678
  _globals['_EXECUTORINPUT_INPUTS_ARTIFACTSENTRY']._serialized_start=13002
  _globals['_EXECUTORINPUT_INPUTS_ARTIFACTSENTRY']._serialized_end=13078
  _globals['_EXECUTORINPUT_INPUTS_PARAMETERVALUESENTRY']._serialized_start=680
  _globals['_EXECUTORINPUT_INPUTS_PARAMETERVALUESENTRY']._serialized_end=758
  _globals['_EXECUTORINPUT_OUTPUTPARAMETER']._serialized_start=13160
  _globals['_EXECUTORINPUT_OUTPUTPARAMETER']._serialized_end=13198
  _globals['_EXECUTORINPUT_OUTPUTS']._serialized_start=13201
  _globals['_EXECUTORINPUT_OUTPUTS']._serialized_end=13549
  _globals['_EXECUTORINPUT_OUTPUTS_PARAMETERSENTRY']._serialized_start=13377
  _globals['_EXECUTORINPUT_OUTPUTS_PARAMETERSENTRY']._serialized_end=13471
  _globals['_EXECUTORINPUT_OUTPUTS_ARTIFACTSENTRY']._serialized_start=13002
  _globals['_EXECUTORINPUT_OUTPUTS_ARTIFACTSENTRY']._serialized_end=13078
  _globals['_EXECUTOROUTPUT']._serialized_start=13552
  _globals['_EXECUTOROUTPUT']._serialized_end=14009
  _globals['_EXECUTOROUTPUT_PARAMETERSENTRY']._serialized_start=608
  _globals['_EXECUTOROUTPUT_PARAMETERSENTRY']._serialized_end=678
  _globals['_EXECUTOROUTPUT_ARTIFACTSENTRY']._serialized_start=13002
  _globals['_EXECUTOROUTPUT_ARTIFACTSENTRY']._serialized_end=13078
  _globals['_EXECUTOROUTPUT_PARAMETERVALUESENTRY']._serialized_start=680
  _globals['_EXECUTOROUTPUT_PARAMETERVALUESENTRY']._serialized_end=758
  _globals['_PIPELINETASKFINALSTATUS']._serialized_start=14012
  _globals['_PIPELINETASKFINALSTATUS']._serialized_end=14213
  _globals['_PIPELINESTATEENUM']._serialized_start=14216
  _globals['_PIPELINESTATEENUM']._serialized_end=14503
  _globals['_PIPELINESTATEENUM_PIPELINETASKSTATE']._serialized_start=14238
  _globals['_PIPELINESTATEENUM_PIPELINETASKSTATE']._serialized_end=14503
  _globals['_PLATFORMSPEC']._serialized_start=14506
  _globals['_PLATFORMSPEC']._serialized_end=14666
  _globals['_PLATFORMSPEC_PLATFORMSENTRY']._serialized_start=14584
  _globals['_PLATFORMSPEC_PLATFORMSENTRY']._serialized_end=14666
  _globals['_SINGLEPLATFORMSPEC']._serialized_start=14669
  _globals['_SINGLEPLATFORMSPEC']._serialized_end=14867
  _globals['_PLATFORMDEPLOYMENTCONFIG']._serialized_start=14870
  _globals['_PLATFORMDEPLOYMENTCONFIG']._serialized_end=15045
  _globals['_PLATFORMDEPLOYMENTCONFIG_EXECUTORSENTRY']._serialized_start=14972
  _globals['_PLATFORMDEPLOYMENTCONFIG_EXECUTORSENTRY']._serialized_end=15045
  _globals['_WORKSPACECONFIG']._serialized_start=15047
  _globals['_WORKSPACECONFIG']._serialized_end=15159
  _globals['_KUBERNETESWORKSPACECONFIG']._serialized_start=15161
  _globals['_KUBERNETESWORKSPACECONFIG']._serialized_end=15261
  _globals['_PIPELINECONFIG']._serialized_start=15263
  _globals['_PIPELINECONFIG']._serialized_end=15370
# @@protoc_insertion_point(module_scope)
